baseStore.BdbIter

|  | ## Cheshire3 Object Model: Class BdbIter

Module baseStore :: Class BdbIter

## Class BdbIter
source code

Object Tree:

    object --+
             |
            BdbIter

Known Subclasses:
  documentStore.BdbDocIter, recordStore.BdbRecordIter, recordStore.MarcIter

Instance Methods

__init__(self, store) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
__iter__(self)
jump(self, position)
next(self)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

cursor |
cxn |
nextData |
store |
Inherited from `object`: `__class__`

Method Details

### __init__(self, store) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __iter__(self) | source code

### jump(self, position) | source code

### next(self) | source code

Class Variable Details

    ### cursor Value:
        None

    ### cxn Value:
        None

    ### nextData Value:
        None

    ### store Value:
        None